==> commons-utils-2.9.0-sources.jar: org/seppiko/commons/utils/jdbc/SqlTypeUtil.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.jdbc;

import java.sql.Date;
import java.sql.Time;
import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.time.ZoneId;
import org.seppiko.commons.utils.reflect.TypeUtil;

/**
 * Sql Type Util
 *
 * @author Leonard Woo
 */
public class SqlTypeUtil {

  private SqlTypeUtil() {}

  /**
   * Convert SQL date and time to LocalDateTime.
   *
   * @param date SQL date.
   * @param time SQL time.
   * @return {@link LocalDateTime}.
   */
  public static LocalDateTime convertSqlDateTime(Date date, Time time) {
    return date.toLocalDate().atTime(time.toLocalTime());
  }

  /**
   * Convert SQL Timestamp with zone to LocalDateTime.
   *
   * @param timestamp SQL Timestamp.
   * @return {@link LocalDateTime}.
   */
  public static LocalDateTime convertSqlTimestamp(Timestamp timestamp) {
    return timestamp.toLocalDateTime();
  }

  /**
   * Convert {@link java.util.Date} to SQL Timestamp
   *
   * @see org.seppiko.commons.utils.DatetimeUtil#toDate(LocalDateTime, ZoneId)
   * @param data {@link java.util.Date}
   * @return SQL Timestamp
   */
  public static Timestamp toSqlTimestamp(java.util.Date data) {
    return new Timestamp(data.getTime());
  }

  /**
   * Convert Sql Object to Class type.
   *
   * @param sqlObj sql object.
   * @param type target class type.
   * @param <T> type.
   * @return Class type object.
   * @throws NullPointerException sql object is null.
   * @throws IllegalArgumentException target type mismatch.
   */
  public static <T> T convertTypeObject(Object sqlObj, Class<T> type) {
    return TypeUtil.convertObject(sqlObj, type);
  }
}

==> commons-utils-2.10.0-sources.jar: org/seppiko/commons/utils/jdbc/SqlTypeUtil.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.jdbc;

import java.sql.Date;
import java.sql.Time;
import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.time.ZoneId;
import org.seppiko.commons.utils.reflect.TypeUtil;

/**
 * Sql Type Util
 *
 * @author Leonard Woo
 */
public class SqlTypeUtil {

  private SqlTypeUtil() {}

  /**
   * Convert SQL {@link Date} and {@link Time} to {@link LocalDateTime}.
   *
   * @param date SQL date.
   * @param time SQL time.
   * @return {@link LocalDateTime} instance.
   */
  public static LocalDateTime convertSqlDateTime(Date date, Time time) {
    return date.toLocalDate().atTime(time.toLocalTime());
  }

  /**
   * Convert SQL {@link Timestamp} with local zone to {@link LocalDateTime}.
   *
   * @param timestamp SQL Timestamp.
   * @return {@link LocalDateTime} instance.
   */
  public static LocalDateTime convertSqlTimestamp(Timestamp timestamp) {
    return timestamp.toLocalDateTime();
  }

  /**
   * Convert {@link java.util.Date} to SQL {@link Timestamp}
   *
   * @see org.seppiko.commons.utils.DatetimeUtil#toDate(LocalDateTime, ZoneId)
   * @param data {@link java.util.Date} instance.
   * @return SQL {@link Timestamp} instance.
   */
  public static Timestamp toSqlTimestamp(java.util.Date data) {
    return new Timestamp(data.getTime());
  }

  /**
   * Convert Sql Object to Class type.
   *
   * @param sqlObj sql object.
   * @param type target class type.
   * @param <T> type.
   * @return Class type instance.
   * @throws NullPointerException sql object is null.
   * @throws IllegalArgumentException target type mismatch.
   */
  public static <T> T convertTypeObject(Object sqlObj, Class<T> type) {
    return TypeUtil.convertObject(sqlObj, type);
  }
}
